Stan Math Library: stan/math/rev/scal/fun/fmax.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
fmax.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/scal/fun/is_nan.hpp>`
`#include <stan/math/prim/scal/fun/is_nan.hpp>`
`#include <boost/math/special_functions/fpclassify.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/likely.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::fmax (const stan::math::var &a, const stan::math::var &b)
| Returns the maximum of the two variable arguments (C99). More...
var | stan::math::fmax (const stan::math::var &a, const double &b)
| Returns the maximum of the variable and scalar, promoting the scalar to a variable if it is larger (C99). More...
var | stan::math::fmax (const double &a, const stan::math::var &b)
| Returns the maximum of a scalar and variable, promoting the scalar to a variable if it is larger (C99). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.